@@ -10,7 +10,7 @@ class Cache:
 
     def _get_cache(self) -> RedisCache:
         if not self._cache_connection:
-            self._cache_connection = RedisCache()
+            self._cache_connection = RedisCache(self._redis_key)
 
         return self._cache_connection
 
@@ -18,7 +18,10 @@ class Cache:
         return self._get_cache().get_string_value(self._redis_key)
 
     def is_redis_cache_version_changed(self) -> bool:
-        return not self._local_cache_version or self.get_redis_cache_version() != self._local_cache_version
+        if self.get_redis_cache_version():
+            return not self._local_cache_version or self.get_redis_cache_version() != self._local_cache_version
+        else:
+            pass
 
     def update_local_cache_version_with_redis_version(self):
         self._local_cache_version = self.get_redis_cache_version()
