@@ -1,14 +1,16 @@
+import json
+
 import redis
 from django.conf import settings
 
-from .exceptions import RedisSettingsNotFoundException, RedisConnectionNotInitialize
+from .exceptions import RGRedisException
 from .. import rg_logger
 
 
 class RedisCache:
     __connection = None
 
-    def __init__(self, redis_settings_key: str = "CACHING_REDIS_SETTINGS"):
+    def __init__(self, redis_settings_key: str = "DEFAULT"):
         self.redis_settings_key = redis_settings_key
 
     def __get_connection(self):
@@ -26,16 +28,23 @@ class RedisCache:
     def __init_redis_connection_with_settings(cls, redis_settings: dict, redis_setting_key: str):
         try:
             if not redis_settings and ("HOST" not in redis_settings or "PORT" not in redis_settings not in "DB" in redis_settings and "PASSWORD" not in redis_settings):
-                raise RedisSettingsNotFoundException(redis_setting_key)
+                raise RGRedisException("Redis setting not proper defined in settings.py, current settings=" + json.dumps(redis_settings))
 
-            connection = redis.Redis(host=redis_settings["HOST"], port=redis_settings["PORT"], db=redis_settings["DB"], password=redis_settings["PASSWORD"], decode_responses=True)
+            connection = redis.Redis(
+                host=redis_settings["HOST"],
+                port=redis_settings["PORT"],
+                db=redis_settings["DB"],
+                password=redis_settings["PASSWORD"],
+                socket_connect_timeout=redis_settings["TIMEOUT"],
+                socket_timeout=redis_settings["TIMEOUT"],
+                decode_responses=True)
 
             if connection:
                 rg_logger.info_important("Host:{}, Port:{}, DB:{}, SettingKey: {}".format(redis_settings["HOST"], redis_settings["PORT"], redis_settings["DB"], redis_setting_key))
 
             return connection
         except Exception as e:
-            rg_logger.exception(e, "RedisCache.__init_redis_connection_with_host()->>")
+            rg_logger.exception(e, "RedisCache->__init_redis_connection_with_host()->>")
 
         return None
 
@@ -46,7 +55,7 @@ class RedisCache:
         if redis_settings_dict and redis_setting_key in redis_settings_dict:
             return redis_settings_dict[redis_setting_key]
         else:
-            raise RedisSettingsNotFoundException(redis_setting_key)
+            raise RGRedisException("Redis setting not proper defined in settings.py, Not found REDIS_SETTINGS or no key=" + redis_setting_key)
 
     def put_value_in_hash_set(self, redis_key: str, _hash_key: str, _hash_value: str):
         redis_connection = self.__get_connection()
@@ -55,10 +64,10 @@ class RedisCache:
             try:
                 redis_connection.hset(redis_key, _hash_key, str(_hash_value))
             except Exception as e:
-                rg_logger.exception(e, "RedisCache.put_value_in_hash_set()->>")
+                rg_logger.exception(e, "RedisCache->put_value_in_hash_set()->>")
                 # raise e
         else:
-            raise RedisConnectionNotInitialize(redis_key)
+            raise RGRedisException("Redis Connection Error for key=" + redis_key + ", method=put_value_in_hash_set")
 
     def get_value_from_hash_set(self, redis_key: str, _key):
         redis_connection = self.__get_connection()
@@ -67,10 +76,10 @@ class RedisCache:
             try:
                 return redis_connection.hget(redis_key, _key)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache.get_value_from_hash_set()->>")
+                rg_logger.exception(e, "RedisCache->get_value_from_hash_set()->>")
                 # raise e
         else:
-            raise RedisConnectionNotInitialize(redis_key)
+            raise RGRedisException("Redis Connection Error for key=" + redis_key + ", method=get_value_from_hash_set")
 
     def get_all_values_from_hash_set(self, _redis_key: str):
         redis_connection = self.__get_connection()
@@ -79,10 +88,10 @@ class RedisCache:
             try:
                 return redis_connection.hgetall(_redis_key)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache.get_all_values_from_hash_set()->>")
+                rg_logger.exception(e, "RedisCache->get_all_values_from_hash_set()->>")
                 # raise e
         else:
-            raise RedisConnectionNotInitialize(_redis_key)
+            raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=get_all_values_from_hash_set")
 
     def remove_value_from_hash_set(self, _redis_key: str, _hash_key: str):
         redis_connection = self.__get_connection()
@@ -91,10 +100,10 @@ class RedisCache:
             try:
                 return redis_connection.hdel(_redis_key, _hash_key)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache.remove_value_from_hash_set()->>")
+                rg_logger.exception(e, "RedisCache->remove_value_from_hash_set()->>")
                 # raise e
         else:
-            raise RedisConnectionNotInitialize(_redis_key)
+            raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=remove_value_from_hash_set")
 
     def delete_key_from_cache(self, _redis_key: str):
         redis_connection = self.__get_connection()
@@ -103,10 +112,10 @@ class RedisCache:
             try:
                 return redis_connection.delete(_redis_key)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache.delete_key_from_cache()->>")
+                rg_logger.exception(e, "RedisCache->delete_key_from_cache()->>")
                 # raise e
         else:
-            raise RedisConnectionNotInitialize(_redis_key)
+            raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=delete_key_from_cache")
 
     def put_string_value(self, _redis_key: str, _value: str):
         redis_connection = self.__get_connection()
@@ -115,10 +124,10 @@ class RedisCache:
             try:
                 return redis_connection.set(_redis_key, _value)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache.put_string_value()->>")
+                rg_logger.exception(e, "RedisCache->put_string_value()->>")
                 # raise e
         else:
-            raise RedisConnectionNotInitialize(_redis_key)
+            raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=put_string_value")
 
     def get_string_value(self, _redis_key):
         redis_connection = self.__get_connection()
@@ -127,10 +136,10 @@ class RedisCache:
             try:
                 return redis_connection.get(_redis_key)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache.get_string_value()->>")
+                rg_logger.exception(e, "RedisCache->get_string_value()->>")
                 # raise e
         else:
-            raise RedisConnectionNotInitialize(_redis_key)
+            raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=get_string_value")
 
     def incr_value(self, _redis_key):
         redis_connection = self.__get_connection()
@@ -139,7 +148,7 @@ class RedisCache:
             try:
                 return redis_connection.incr(_redis_key)
             except Exception as e:
-                rg_logger.exception(e, "RedisCache.get_string_value()->>")
+                rg_logger.exception(e, "RedisCache->get_string_value()->>")
                 # raise e
         else:
-            raise RedisConnectionNotInitialize(_redis_key)
+            raise RGRedisException("Redis Connection Error for key=" + _redis_key + ", method=incr_value")
